@@ -26,6 +26,8 @@ from influxdb.exceptions import InfluxDBClientError
 from influxdb.tests import skip_if_pypy, using_pypy, skip_server_tests
 from influxdb.tests.server_tests.base import ManyTestCasesWithServerMixin
 from influxdb.tests.server_tests.base import SingleTestCaseWithServerMixin
+from influxdb.tests.server_tests.base import ManyTestCasesWithServerGzipMixin
+from influxdb.tests.server_tests.base import SingleTestCaseWithServerGzipMixin
 
 # By default, raise exceptions on warnings
 warnings.simplefilter('error', FutureWarning)
@@ -450,6 +452,33 @@ class CommonTests(ManyTestCasesWithServerMixin, unittest.TestCase):
         self.assertIn(12, net_out['series'][0]['values'][0])
         self.assertIn(12.34, cpu['series'][0]['values'][0])
 
+    def test_write_points_batch_generator(self):
+        """Test writing points in a batch from a generator."""
+        dummy_points = [
+            {"measurement": "cpu_usage", "tags": {"unit": "percent"},
+                "time": "2009-11-10T23:00:00Z", "fields": {"value": 12.34}},
+            {"measurement": "network", "tags": {"direction": "in"},
+                "time": "2009-11-10T23:00:00Z", "fields": {"value": 123.00}},
+            {"measurement": "network", "tags": {"direction": "out"},
+                "time": "2009-11-10T23:00:00Z", "fields": {"value": 12.00}}
+        ]
+        dummy_points_generator = (point for point in dummy_points)
+        self.cli.write_points(points=dummy_points_generator,
+                              tags={"host": "server01",
+                                    "region": "us-west"},
+                              batch_size=2)
+        time.sleep(5)
+        net_in = self.cli.query("SELECT value FROM network "
+                                "WHERE direction=$dir",
+                                bind_params={'dir': 'in'}
+                                ).raw
+        net_out = self.cli.query("SELECT value FROM network "
+                                 "WHERE direction='out'").raw
+        cpu = self.cli.query("SELECT value FROM cpu_usage").raw
+        self.assertIn(123, net_in['series'][0]['values'][0])
+        self.assertIn(12, net_out['series'][0]['values'][0])
+        self.assertIn(12.34, cpu['series'][0]['values'][0])
+
     def test_query(self):
         """Test querying data back from server."""
         self.assertIs(True, self.cli.write_points(dummy_point))
@@ -817,6 +846,64 @@ GROUP BY tag_1').get_points())
         ]
         self.cli.write_points(pts)
 
+    def test_get_list_series(self):
+        """Test get a list of series from the database."""
+        dummy_points = [
+            {
+                "measurement": "cpu_load_short",
+                "tags": {
+                    "host": "server01",
+                    "region": "us-west"
+                },
+                "time": "2009-11-10T23:00:00.123456Z",
+                "fields": {
+                    "value": 0.64
+                }
+            }
+        ]
+
+        dummy_points_2 = [
+            {
+                "measurement": "memory_usage",
+                "tags": {
+                    "host": "server02",
+                    "region": "us-east"
+                },
+                "time": "2009-11-10T23:00:00.123456Z",
+                "fields": {
+                    "value": 80
+                }
+            }
+        ]
+
+        self.cli.write_points(dummy_points)
+        self.cli.write_points(dummy_points_2)
+
+        self.assertEquals(
+            self.cli.get_list_series(),
+            ['cpu_load_short,host=server01,region=us-west',
+             'memory_usage,host=server02,region=us-east']
+        )
+
+        self.assertEquals(
+            self.cli.get_list_series(measurement='memory_usage'),
+            ['memory_usage,host=server02,region=us-east']
+        )
+
+        self.assertEquals(
+            self.cli.get_list_series(measurement='memory_usage'),
+            ['memory_usage,host=server02,region=us-east']
+        )
+
+        self.assertEquals(
+            self.cli.get_list_series(tags={'host': 'server02'}),
+            ['memory_usage,host=server02,region=us-east'])
+
+        self.assertEquals(
+            self.cli.get_list_series(
+                measurement='cpu_load_short', tags={'host': 'server02'}),
+            [])
+
 
 @skip_server_tests
 class UdpTests(ManyTestCasesWithServerMixin, unittest.TestCase):
@@ -855,3 +942,25 @@ class UdpTests(ManyTestCasesWithServerMixin, unittest.TestCase):
             ],
             list(rsp['cpu_load_short'])
         )
+
+
+# Run the tests again, but with gzip enabled this time
+@skip_server_tests
+class GzipSimpleTests(SimpleTests, SingleTestCaseWithServerGzipMixin):
+    """Repeat the simple tests with InfluxDBClient where gzip=True."""
+
+    pass
+
+
+@skip_server_tests
+class GzipCommonTests(CommonTests, ManyTestCasesWithServerGzipMixin):
+    """Repeat the common tests with InfluxDBClient where gzip=True."""
+
+    pass
+
+
+@skip_server_tests
+class GzipUdpTests(UdpTests, ManyTestCasesWithServerGzipMixin):
+    """Repeat the UDP tests with InfluxDBClient where gzip=True."""
+
+    pass
